summaryrefslogtreecommitdiffstats
path: root/kalyptus/kalyptusCxxToDcopIDL.pm
diff options
context:
space:
mode:
Diffstat (limited to 'kalyptus/kalyptusCxxToDcopIDL.pm')
-rw-r--r--kalyptus/kalyptusCxxToDcopIDL.pm18
1 files changed, 9 insertions, 9 deletions
diff --git a/kalyptus/kalyptusCxxToDcopIDL.pm b/kalyptus/kalyptusCxxToDcopIDL.pm
index ad7e3eee..5ff17c02 100644
--- a/kalyptus/kalyptusCxxToDcopIDL.pm
+++ b/kalyptus/kalyptusCxxToDcopIDL.pm
@@ -131,14 +131,14 @@ BEGIN
'TQEventLoop::ProcessEventsFlags' => 'uint',
'TQStyle::SCFlags' => 'int',
'TQStyle::SFlags' => 'int',
- 'Q_INT16' => 'short',
- 'Q_INT32' => 'int',
- 'Q_INT8' => 'char',
- 'Q_LONG' => 'long',
- 'Q_UINT16' => 'ushort',
- 'Q_UINT32' => 'uint',
- 'Q_UINT8' => 'uchar',
- 'Q_ULONG' => 'long',
+ 'TQ_INT16' => 'short',
+ 'TQ_INT32' => 'int',
+ 'TQ_INT8' => 'char',
+ 'TQ_LONG' => 'long',
+ 'TQ_UINT16' => 'ushort',
+ 'TQ_UINT32' => 'uint',
+ 'TQ_UINT8' => 'uchar',
+ 'TQ_ULONG' => 'long',
);
}
@@ -836,7 +836,7 @@ sub registerType($$) {
}
# Apply typedefs, and store the resulting type.
# For instance, if $type was Q_UINT16&, realType will be ushort
$allTypes{$type}{realType} = applyTypeDef( $realType );
# In the first phase we only create entries into allTypes.
@@ -836,7 +836,7 @@ sub registerType($$) {
}
# Apply typedefs, and store the resulting type.
- # For instance, if $type was Q_UINT16&, realType will be ushort
+ # For instance, if $type was TQ_UINT16&, realType will be ushort
$allTypes{$type}{realType} = applyTypeDef( $realType );
# In the first phase we only create entries into allTypes.